@@ -31,8 +31,7 @@ class Parameters(Enum):
     TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_TIMESTAMP_KEY
     AGGREGATION_MEASURE = "aggregationMeasure"
     BUSINESS_HOURS = "business_hours"
-    WORKTIMING  = "worktiming"
-    WEEKENDS = "weekends"
+    BUSINESS_HOUR_SLOTS = "business_hour_slots"
     WORKCALENDAR = "workcalendar"
 
 
@@ -55,11 +54,15 @@ def performance(log: Union[EventLog, EventStream], parameters: Optional[Dict[Uni
             timestamp_key -> Attribute to use as timestamp
         - Parameters.BUSINESS_HOURS => calculates the difference of time based on the business hours, not the total time.
                                         Default: False
-        - Parameters.WORKTIMING => work schedule of the company (provided as a list where the first number is the start
-            of the work time, and the second number is the end of the work time), if business hours are enabled
-                                        Default: [7, 17] (work shift from 07:00 to 17:00)
-        - Parameters.WEEKENDS => indexes of the days of the week that are weekend
-                                        Default: [6, 7] (weekends are Saturday and Sunday)
+        - Parameters.BUSINESS_HOURS_SLOTS =>
+        work schedule of the company, provided as a list of tuples where each tuple represents one time slot of business
+        hours. One slot i.e. one tuple consists of one start and one end time given in seconds since week start, e.g.
+        [
+            (7 * 60 * 60, 17 * 60 * 60),
+            ((24 + 7) * 60 * 60, (24 + 12) * 60 * 60),
+            ((24 + 13) * 60 * 60, (24 + 17) * 60 * 60),
+        ]
+        meaning that business hours are Mondays 07:00 - 17:00 and Tuesdays 07:00 - 12:00 and 13:00 - 17:00
     Returns
     -------
     dfg
@@ -76,16 +79,16 @@ def performance(log: Union[EventLog, EventStream], parameters: Optional[Dict[Uni
     aggregation_measure = exec_utils.get_param_value(Parameters.AGGREGATION_MEASURE, parameters, "mean")
 
     business_hours = exec_utils.get_param_value(Parameters.BUSINESS_HOURS, parameters, False)
-    worktiming = exec_utils.get_param_value(Parameters.WORKTIMING, parameters, [7, 17])
-    weekends = exec_utils.get_param_value(Parameters.WEEKENDS, parameters, [6, 7])
+    business_hours_slots = exec_utils.get_param_value(Parameters.BUSINESS_HOUR_SLOTS, parameters, constants.DEFAULT_BUSINESS_HOUR_SLOTS)
+
     workcalendar = exec_utils.get_param_value(Parameters.WORKCALENDAR, parameters, constants.DEFAULT_BUSINESS_HOURS_WORKCALENDAR)
 
     if business_hours:
         dfgs0 = map((lambda t: [
             ((t[i - 1][activity_key], t[i][activity_key]),
              max(0, BusinessHours(t[i - 1][timestamp_key].replace(tzinfo=None),
-                                  t[i][start_timestamp_key].replace(tzinfo=None), worktiming=worktiming,
-                                  weekends=weekends, workcalendar=workcalendar).getseconds()))
+                                  t[i][start_timestamp_key].replace(tzinfo=None),
+                                  business_hour_slots=business_hours_slots, workcalendar=workcalendar).get_seconds()))
             for i in range(1, len(t))]), log)
     else:
         dfgs0 = map((lambda t: [
