@@ -20,9 +20,10 @@ from pm4py.util import variants_util
 from enum import Enum
 from pm4py.util import constants
 
-from typing import Optional, Dict, Any, Union, Tuple, List
-from pm4py.objects.log.obj import EventLog, EventStream
+from typing import Optional, Dict, Any, Union
 import pandas as pd
+from pm4py.objects.org.sna.obj import SNA
+from collections import Counter
 
 
 class Parameters(Enum):
@@ -32,7 +33,7 @@ class Parameters(Enum):
     METRIC_NORMALIZATION = "metric_normalization"
 
 
-def apply(log: pd.DataFrame, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> List[Any]:
+def apply(log: pd.DataFrame, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> SNA:
     """
     Calculates the Working Together metric
 
@@ -53,7 +54,6 @@ def apply(log: pd.DataFrame, parameters: Optional[Dict[Union[str, Parameters], A
     if parameters is None:
         parameters = {}
 
-    import numpy
     from pm4py.statistics.traces.generic.pandas import case_statistics
 
     resource_key = exec_utils.get_param_value(Parameters.RESOURCE_KEY, parameters, xes.DEFAULT_RESOURCE_KEY)
@@ -69,7 +69,7 @@ def apply(log: pd.DataFrame, parameters: Optional[Dict[Union[str, Parameters], A
 
     flat_list = sorted(list(set([item for sublist in resources for item in sublist])))
 
-    metric_matrix = numpy.zeros((len(flat_list), len(flat_list)))
+    connections = Counter()
 
     for idx, rv in enumerate(resources):
         rvj = variants_resources[idx]
@@ -79,7 +79,7 @@ def apply(log: pd.DataFrame, parameters: Optional[Dict[Union[str, Parameters], A
             res_i = flat_list.index(ord_res_list[i])
             for j in range(i + 1, len(ord_res_list)):
                 res_j = flat_list.index(ord_res_list[j])
-                metric_matrix[res_i, res_j] += float(variants_occ[rvj]) / float(len(log))
-                metric_matrix[res_j, res_i] += float(variants_occ[rvj]) / float(len(log))
+                connections[(flat_list[res_i], flat_list[res_j])] += float(variants_occ[rvj]) / float(len(log))
+                connections[(flat_list[res_j], flat_list[res_i])] += float(variants_occ[rvj]) / float(len(log))
 
-    return [metric_matrix, flat_list, False]
+    return SNA(dict(connections), False)
