@@ -14,5 +14,5 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.transformation.ocel.features import objects, events
 
+from pm4py.algo.transformation.ocel.features import objects, events, events_objects
