@@ -14,4 +14,5 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.visualization.common import save, utils, gview, visualizer
+
+from pm4py.visualization.common import save, utils, gview, visualizer, dot_util
