@@ -59,7 +59,7 @@ def get_decorations(log, net, initial_marking, final_marking, parameters=None, m
     ht_perf_method
         Method to use in order to annotate hidden transitions (performance value could be put on the last possible
         point (last) or in the first possible point (first)
-
+    
     Returns
     ------------
     decorations
@@ -89,7 +89,8 @@ def get_decorations(log, net, initial_marking, final_marking, parameters=None, m
                                                                    aligned_traces, variants_idx,
                                                                    activity_key=activity_key,
                                                                    timestamp_key=timestamp_key,
-                                                                   ht_perf_method=ht_perf_method)
+                                                                   ht_perf_method=ht_perf_method,
+                                                                   parameters=parameters)
 
     aggregated_statistics = performance_map.aggregate_statistics(element_statistics, measure=measure,
                                                                  aggregation_measure=aggregation_measure)
